@@ -4,7 +4,6 @@ import re
 import requests
 import smokesignal
 
-from BeautifulSoup import BeautifulSoup
 from requests.auth import HTTPBasicAuth
 from twisted.internet import reactor
 
@@ -44,11 +43,15 @@ def find_jira_numbers(message):
 
     pat = r'(https?://.*?)?(({0})-\d+)($|[\s\W]+)'.format('|'.join(JIRA_PATTERNS))
     tickets = []
-    for match in re.findall(pat, message, re.IGNORECASE):
-        # if match[0] is not empty, the ticket is in a URL. Ignore it
-        if match[0]:
+
+    if not JIRA_PATTERNS:
+        return tickets
+
+    for matched in re.findall(pat, message, re.IGNORECASE):
+        # if matched[0] is not empty, the ticket is in a URL. Ignore it
+        if matched[0]:
             continue
-        tickets.append(match[1])
+        tickets.append(matched[1])
 
     return tickets
 
@@ -104,23 +107,6 @@ def jira_command(client, channel, nick, message, cmd, args):
     return None
 
 
-def _soup_desc(ticket, url, auth=None):
-    resp = requests.get(url, auth=auth)
-
-    try:
-        resp.raise_for_status()
-    except:
-        logger.error('Error getting JIRA ticket %s. Status %s', url, resp.status_code)
-        return
-
-    try:
-        soup = BeautifulSoup(resp.content)
-        title = soup.find('h2', attrs={'id': 'issue_header_summary'}).text
-        return u'[{0}] {1} ({2})'.format(ticket.upper(), title, url)
-    except:
-        return u'[{0}] {1}'.format(ticket.upper(), url)
-
-
 def _rest_desc(ticket, url, auth=None):
     api_url = to_unicode(settings.JIRA_REST_API)
     resp = requests.get(api_url.format(ticket=ticket), auth=auth)
@@ -142,16 +128,15 @@ def jira_full_descriptions(client, channel, urls):
     Meant to be run asynchronously because it uses the network
     """
     descriptions = []
-    fn = _soup_desc if getattr(settings, 'JIRA_REST_API', '') == '' else _rest_desc
-
     user_pass = getattr(settings, 'JIRA_AUTH', ('', ''))
+
     if all(user_pass):
         auth = HTTPBasicAuth(*user_pass)
     else:
         auth = None
 
     for ticket, url in urls.iteritems():
-        desc = fn(ticket, url, auth)
+        desc = _rest_desc(ticket, url, auth)
         if desc is not None:
             descriptions.append(desc)
 
@@ -161,7 +146,7 @@ def jira_full_descriptions(client, channel, urls):
 
 def jira_match(client, channel, nick, message, matches):
     jira_url = to_unicode(settings.JIRA_URL)
-    full_urls = dict(map(lambda s: (s, jira_url.format(ticket=s)), matches))
+    full_urls = dict((s, jira_url.format(ticket=s)) for s in matches)
 
     if not getattr(settings, 'JIRA_SHOW_FULL_DESCRIPTION', True):
         return u'{0} might be talking about JIRA ticket: {1}'.format(nick, ', '.join(full_urls.values()))
